<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="93"/>
        <location filename="../mainwindow.cpp" line="1807"/>
        <location filename="../mainwindow.cpp" line="1822"/>
        <source>MX Package Installer</source>
        <translation>Εγκατάσταση πακέτων του MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>Δημοφιλείς εφαρμογές</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <location filename="../mainwindow.cpp" line="96"/>
        <source>Package</source>
        <translation>Πακέτο </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <location filename="../mainwindow.cpp" line="96"/>
        <source>Info</source>
        <translation>Πληροφορίες</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="250"/>
        <location filename="../mainwindow.ui" line="653"/>
        <location filename="../mainwindow.ui" line="975"/>
        <location filename="../mainwindow.cpp" line="96"/>
        <source>Description</source>
        <translation>Περιγραφή</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="113"/>
        <location filename="../mainwindow.ui" line="216"/>
        <location filename="../mainwindow.ui" line="619"/>
        <location filename="../mainwindow.ui" line="944"/>
        <location filename="../mainwindow.ui" line="1208"/>
        <source>search</source>
        <translation>aναζήτηση </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="123"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;p&gt;Greyed out items have already been installed.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Διαχειρηση πρόσθετων πακέτων&lt;/ span&gt;&lt;/ p&gt;&lt;p&gt;Τα γκριζαρισμένα στοιχεία έχουν ήδη εγκατασταθεί.&lt;/p&gt;&lt;/ body&gt;&lt;/ html&gt; </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="153"/>
        <source>Stable Repo</source>
        <translation>Αποθετήριο Stable</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="174"/>
        <location filename="../mainwindow.ui" line="564"/>
        <location filename="../mainwindow.ui" line="889"/>
        <location filename="../mainwindow.ui" line="1156"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Επιλέξτε τα πακέτα ανάλογα με την κατάστασή τους.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="177"/>
        <location filename="../mainwindow.ui" line="181"/>
        <location filename="../mainwindow.ui" line="567"/>
        <location filename="../mainwindow.ui" line="571"/>
        <location filename="../mainwindow.ui" line="892"/>
        <location filename="../mainwindow.ui" line="896"/>
        <location filename="../mainwindow.cpp" line="2198"/>
        <source>All packages</source>
        <translation>Ολα τα Πακέτa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="186"/>
        <location filename="../mainwindow.ui" line="576"/>
        <location filename="../mainwindow.ui" line="901"/>
        <location filename="../mainwindow.cpp" line="2212"/>
        <source>Installed</source>
        <translation>Εγκαταστημένο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="191"/>
        <location filename="../mainwindow.ui" line="581"/>
        <location filename="../mainwindow.ui" line="906"/>
        <location filename="../mainwindow.cpp" line="2210"/>
        <source>Upgradable</source>
        <translation>Αναβαθμίση</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="196"/>
        <location filename="../mainwindow.ui" line="586"/>
        <location filename="../mainwindow.ui" line="911"/>
        <location filename="../mainwindow.ui" line="1188"/>
        <location filename="../mainwindow.cpp" line="2177"/>
        <location filename="../mainwindow.cpp" line="2214"/>
        <location filename="../mainwindow.cpp" line="2303"/>
        <source>Not installed</source>
        <translation>Μην Εγκαταστημένο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="240"/>
        <location filename="../mainwindow.ui" line="643"/>
        <location filename="../mainwindow.ui" line="965"/>
        <source>Package Name</source>
        <translation>Όνομα πακέτου</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="245"/>
        <location filename="../mainwindow.ui" line="648"/>
        <location filename="../mainwindow.ui" line="970"/>
        <location filename="../mainwindow.ui" line="1243"/>
        <source>Version</source>
        <translation>Έκδοση</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="277"/>
        <location filename="../mainwindow.ui" line="680"/>
        <location filename="../mainwindow.ui" line="1002"/>
        <source>Total packages:</source>
        <translation>Ολα τα Πακέτa</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="307"/>
        <location filename="../mainwindow.ui" line="710"/>
        <location filename="../mainwindow.ui" line="1032"/>
        <source>Installed:</source>
        <translation>Εγκαταστημένο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="337"/>
        <location filename="../mainwindow.ui" line="740"/>
        <location filename="../mainwindow.ui" line="1062"/>
        <source>Upgradable:</source>
        <translation>Αναβαθμίση</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <location filename="../mainwindow.ui" line="1313"/>
        <source>Upgrade All</source>
        <translation>Αναβάθμιση όλων</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="378"/>
        <location filename="../mainwindow.ui" line="767"/>
        <location filename="../mainwindow.ui" line="1089"/>
        <source>Hide library and developer packages</source>
        <translation>Απόκρυψη πακέτων βιβλιοθήκης και προγραμματιστών</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="400"/>
        <location filename="../mainwindow.ui" line="789"/>
        <location filename="../mainwindow.ui" line="1111"/>
        <source>Refresh list</source>
        <translation> Ανανέωση λιστας</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="417"/>
        <location filename="../mainwindow.ui" line="594"/>
        <location filename="../mainwindow.ui" line="919"/>
        <location filename="../mainwindow.ui" line="1456"/>
        <source>Greyed out items have already been installed.</source>
        <translation>Γκριζαρισμένα στοιχεία έχουν ήδη εγκατασταθεί.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="473"/>
        <location filename="../mainwindow.ui" line="536"/>
        <location filename="../mainwindow.ui" line="856"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= Upgradable package. Newer version available in selected repository.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;= Δυνατότητα αναβάθμισης του πακέτου. Νεότερη έκδοση διαθέσιμη στο επιλεγμένο αποθετήριο.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <source>MX Test Repo</source>
        <translation>MX Test Repo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="813"/>
        <source>Debian Backports</source>
        <translation>Debian Backports</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1135"/>
        <source>Flatpaks</source>
        <translation>Flatpaks</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1159"/>
        <location filename="../mainwindow.ui" line="1163"/>
        <location filename="../mainwindow.cpp" line="2158"/>
        <source>All apps</source>
        <translation>Όλες οι εφαρμογές</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1168"/>
        <location filename="../mainwindow.cpp" line="2163"/>
        <source>All runtimes</source>
        <translation>Όλες οι ώρες εκτέλεσης</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1173"/>
        <location filename="../mainwindow.cpp" line="2168"/>
        <source>All available</source>
        <translation>Όλα διαθέσιμα</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1178"/>
        <location filename="../mainwindow.cpp" line="2156"/>
        <location filename="../mainwindow.cpp" line="2298"/>
        <source>Installed apps</source>
        <translation>Εγκατεστημένες εφαρμογές</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1183"/>
        <location filename="../mainwindow.cpp" line="2154"/>
        <source>Installed runtimes</source>
        <translation>Εγκατεστημένες ώρες εκτέλεσης</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1233"/>
        <source>Short Name</source>
        <translation>Μικρό όνομα</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1238"/>
        <source>Full Package Name</source>
        <translation>Πλήρες Όνομα Πακέτου</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1248"/>
        <source>Size</source>
        <translation>Μέγεθος</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1292"/>
        <source>Total items </source>
        <translation>Συνολικά στοιχεία</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1306"/>
        <source>Installed apps:</source>
        <translation>Εγκατεστημένες εφαρμογές:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1359"/>
        <source>Advanced</source>
        <translation>Προχωρημένα</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1389"/>
        <source>Total installed size:</source>
        <translation>Συνολικό εγκατεστημένο μέγεθος:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1406"/>
        <location filename="../mainwindow.ui" line="1410"/>
        <source>For all users</source>
        <translation>Για όλους τους χρήστες</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1415"/>
        <source>For current user</source>
        <translation>Για τον τρέχοντα χρήστη</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1433"/>
        <source>Remote (repo):</source>
        <translation>Απομακρυσμένο (αποθετήριο):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1476"/>
        <location filename="../mainwindow.cpp" line="1988"/>
        <location filename="../mainwindow.cpp" line="2112"/>
        <source>Console Output</source>
        <translation>Έξοδος της κονσόλας</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1493"/>
        <source>Respond here, or just press Enter</source>
        <translation>Απαντήστε εδώ ή απλά πατήστε Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1537"/>
        <source>Uninstall</source>
        <translation>Αφαίρεση</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1544"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1560"/>
        <source>About this application</source>
        <translation>Περί εφαρμογής.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1563"/>
        <source>About...</source>
        <translation>Περί</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1570"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1618"/>
        <source>Display help </source>
        <translation>Δείτε Βοήθεια</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1621"/>
        <source>Help</source>
        <translation>Βοήθεια </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1628"/>
        <source>Alt+H</source>
        <translation>Alt+H </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1644"/>
        <location filename="../mainwindow.cpp" line="1891"/>
        <location filename="../mainwindow.cpp" line="2292"/>
        <location filename="../mainwindow.cpp" line="2295"/>
        <source>Install</source>
        <translation>Εγκατάσταση </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1651"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1670"/>
        <source>Quit application</source>
        <translation>Κλείστε την εφαρμογή </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1673"/>
        <source>Close</source>
        <translation>Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1680"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="147"/>
        <source>Uninstalling packages...</source>
        <translation>Αφαίρεση </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="153"/>
        <source>Running post-uninstall operations...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="170"/>
        <source>Refreshing sources...</source>
        <translation>Ενημέρωση πηγών</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="183"/>
        <location filename="../mainwindow.cpp" line="944"/>
        <location filename="../mainwindow.cpp" line="1061"/>
        <location filename="../mainwindow.cpp" line="1177"/>
        <location filename="../mainwindow.cpp" line="1771"/>
        <location filename="../mainwindow.cpp" line="1786"/>
        <location filename="../mainwindow.cpp" line="1796"/>
        <location filename="../mainwindow.cpp" line="1959"/>
        <location filename="../mainwindow.cpp" line="1979"/>
        <location filename="../mainwindow.cpp" line="2382"/>
        <location filename="../mainwindow.cpp" line="2456"/>
        <location filename="../mainwindow.cpp" line="2483"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="183"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation>Παρουσιάστηκε πρόβλημα κατά την ενημέρωση των πηγών. Ορισμένες πηγές ενδέχεται να μην έχουν παράσχει ενημερώσεις. Για περισσότερες πληροφορίες, ελέγξτε:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="544"/>
        <location filename="../mainwindow.cpp" line="1813"/>
        <source>Cancel</source>
        <translation>Ακύρωση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="550"/>
        <source>Please wait...</source>
        <translation>Παρακαλώ περιμένετε...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="751"/>
        <location filename="../mainwindow.cpp" line="769"/>
        <source>Version </source>
        <translation>Έκδοση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="751"/>
        <source> in stable repo</source>
        <translation>σε stable αποθετήριο</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="753"/>
        <source>Not available in stable repo</source>
        <translation>Δεν διατίθεται σε </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <location filename="../mainwindow.cpp" line="2093"/>
        <source>Latest version </source>
        <translation>Τελευταία έκδοση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="763"/>
        <location filename="../mainwindow.cpp" line="2093"/>
        <source> already installed</source>
        <translation>ήδη εγκαταστημένο</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="769"/>
        <source> installed</source>
        <translation>εγκαταστημένο</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="879"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation>Πρόκειται να χρησιμοποιήσετε τον αποθετήριο MX Test, του οποίου τα πακέτα παρέχονται μόνο για σκοπούς δοκιμής. Είναι πιθανό να σπάσει το σύστημά σας, επομένως προτείνεται να δημιουργήσετε αντίγραφα ασφαλείας του συστήματός σας και να εγκαταστήσετε ή να ενημερώσετε μόνο ένα πακέτο τη φορά. Παρακαλούμε δώστε σχόλια στο Φόρουμ έτσι ώστε το πακέτο να μπορεί να αξιολογηθεί πριν μετακινηθείτε στο Main.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="888"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>Είστε έτοιμοι να χρησιμοποιήσετε το Debian backports, το οποίο περιέχει πακέτα που λαμβάνονται από την επόμενη έκδοση του Debian (που ονομάζεται «testing»), με ρυθμίσεις και ανασύνθεσεις για χρήση στο Debian stable. Δεν μπορούν να ελεγχθούν ως εκτενώς και στις σταθερές εκδόσεις του Debian και το MX Linux, και παρέχονται πάνω σε ΩΣ ΕΧΕΙ βάση, με κίνδυνο ασυμβατότητες με άλλα συστατικά στο Debian stable. Χρησιμοποιήστε το με προσοχή!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="896"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation>Το MX Linux περιλαμβάνει αυτό το αποθετήριο flatpaks μόνο για την ευκολία των χρηστών και δεν είναι υπεύθυνο για τη λειτουργικότητα των επιμέρους flatpaks. Για περισσότερα, συμβουλευτείτε flatpaks στο Wiki.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="905"/>
        <source>Warning</source>
        <translation>Προειδοποίηση </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="909"/>
        <source>Do not show this message again</source>
        <translation>Να μην εμφανιστεί ξανά αυτό το μήνυμα</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="944"/>
        <location filename="../mainwindow.cpp" line="1061"/>
        <location filename="../mainwindow.cpp" line="1177"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>Το Internet δεν είναι διαθέσιμο, δεν θα είναι δυνατή η λήψη της λίστας των πακέτων</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="949"/>
        <source>Installing packages...</source>
        <translation>Εγκατάσταση πακέτων...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="989"/>
        <source>Post-processing...</source>
        <translation>Μετα-επεξεργασία ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1021"/>
        <source>Pre-processing for </source>
        <translation>Προ-επεξεργασία ... </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1035"/>
        <source>Installing </source>
        <translation>Εγκατάσταση </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1043"/>
        <source>Post-processing for </source>
        <translation>Μετα-επεξεργασία ...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1187"/>
        <source>Downloading package info...</source>
        <translation>Λήψη πληροφοριών πακέτων...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1612"/>
        <source>Packages to be installed: </source>
        <translation>Τα πακέτα που πρόκειται να εγκατασταθεί: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1649"/>
        <source>Package info</source>
        <translation>Πληροφορίες πακέτου</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1767"/>
        <location filename="../mainwindow.cpp" line="1780"/>
        <location filename="../mainwindow.cpp" line="1793"/>
        <location filename="../mainwindow.cpp" line="1954"/>
        <location filename="../mainwindow.cpp" line="2378"/>
        <location filename="../mainwindow.cpp" line="2450"/>
        <location filename="../mainwindow.cpp" line="2477"/>
        <source>Done</source>
        <translation>Ολοκληρώθηκε</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1767"/>
        <location filename="../mainwindow.cpp" line="1780"/>
        <location filename="../mainwindow.cpp" line="1793"/>
        <location filename="../mainwindow.cpp" line="1954"/>
        <location filename="../mainwindow.cpp" line="1972"/>
        <location filename="../mainwindow.cpp" line="2378"/>
        <location filename="../mainwindow.cpp" line="2450"/>
        <location filename="../mainwindow.cpp" line="2477"/>
        <source>Processing finished successfully.</source>
        <translation>Η επεξεργασία ολοκληρώθηκε με επιτυχία.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1771"/>
        <location filename="../mainwindow.cpp" line="1786"/>
        <location filename="../mainwindow.cpp" line="1796"/>
        <location filename="../mainwindow.cpp" line="2382"/>
        <location filename="../mainwindow.cpp" line="2456"/>
        <location filename="../mainwindow.cpp" line="2483"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation>Ένα πρόβλημα εντοπίστηκε κατά την εγκατάσταση, ελέγξτε την έξοδο της κονσόλας.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1806"/>
        <source>About MX Package Installer</source>
        <translation>Περί </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1807"/>
        <source>Version: </source>
        <translation>Έκδοση:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1808"/>
        <source>Package Installer for MX Linux</source>
        <translation>Εγκατάσταση πακέτων του MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1810"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c)  MX Linux </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1811"/>
        <location filename="../mainwindow.cpp" line="1822"/>
        <source>License</source>
        <translation>Άδεια</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1812"/>
        <source>Changelog</source>
        <translation>Changelog</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1834"/>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1889"/>
        <source>Reinstall</source>
        <translation>Επανεγκατάσταση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1959"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation>Παρουσιάστηκε πρόβλημα κατά την απεγκατάσταση, ελέγξτε το αρχείο εξόδου</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1972"/>
        <source>Success</source>
        <translation>Επιτυχία!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1979"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation>Παρουσιάστηκε πρόβλημα κατά την απεγκατάσταση του προγράμματος</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2069"/>
        <location filename="../mainwindow.cpp" line="2080"/>
        <source>Flatpak not installed</source>
        <translation>Το Flatpak δεν είναι εγκατεστημένο </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2069"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation>Το Flatpak δεν είναι εγκατεστημένο.
Εντάξει για να προχωρήσει και να το εγκαταστήσετε;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2080"/>
        <source>Flatpak was not installed</source>
        <translation>Το Flatpak δεν εγκαταστάθηκε</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2100"/>
        <location filename="../mainwindow.cpp" line="2118"/>
        <source>Flathub remote failed</source>
        <translation>Το Flathub απέτυχε</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2100"/>
        <location filename="../mainwindow.cpp" line="2118"/>
        <source>Flathub remote could not be added</source>
        <translation>Δεν ήταν δυνατή η προσθήκη Flathub</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2108"/>
        <source>Needs re-login</source>
        <translation>Χρειάζεστε ξανά σύνδεση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2108"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation>Ίσως χρειαστεί να αποσυνδεθείτε/συνδεθείτε για να δείτε τα εγκατεστημένα στοιχεία στο μενού</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2290"/>
        <source>Upgrade</source>
        <translation>Αναβάθμιση</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2409"/>
        <source>Quit?</source>
        <translation>βγείτε;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2410"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation>Η διαδικασία εκτελείται ακόμα και η διακοπή μπορεί να αφήσει το σύστημα σε ασταθή κατάσταση. &lt;p&gt;&lt;b&gt;Είστε βέβαιοι ότι θέλετε να βγείτε από το MX Package Installer;&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="vanished">Ναι</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="vanished">Όχι</translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="14"/>
        <source>Manage Flatpak Remotes</source>
        <translation>Διαχείριση Flatpak Remotes</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For all users</source>
        <translation>Για όλους τους χρήστες</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="24"/>
        <source>For current user</source>
        <translation>Για τον τρέχοντα χρήστη</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="30"/>
        <source>enter Flatpak remote URL</source>
        <translation>εισάγετε απομακρυσμένη διεύθυνση URL Flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="33"/>
        <source>enter Flatpakref location to install app</source>
        <translation>εισάγετε την τοποθεσία Flatpakref για να εγκαταστήσετε την εφαρμογή</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="35"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation>Προσθέστε ή αφαιρέστε απομακρυσμένα flatpak (repos) ή εγκαταστήστε εφαρμογές χρησιμοποιώντας URL ή διαδρομή flatpakref</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="44"/>
        <source>Remove remote</source>
        <translation>Αφαίρεση remote</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="49"/>
        <source>Add remote</source>
        <translation>Προσθήκη remote</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="54"/>
        <source>Install app</source>
        <translation>Εγκαταστήστε την εφαρμογή</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="59"/>
        <source>Close</source>
        <translation>Κλείσε</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Not removable</source>
        <translation>Δεν είναι αφαιρούμενο</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation>Το Flathub είναι το κύριο remote Flatpak και δε θα αφαιρεθεί</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="97"/>
        <source>Error adding remote</source>
        <translation>Σφάλμα κατά την προσθήκη remote</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="97"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation>Δεν ήταν δυνατή η προσθήκη remote - η εντολή επέστρεψε ένα σφάλμα. Ελέγξτε ξανά τη διεύθυνση απομακρυσμένης σύνδεσης και δοκιμάστε ξανά</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Success</source>
        <translation>Επιτυχία!</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Remote added successfully</source>
        <translation>Remote προστέθηκε με επιτυχία</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Unable to get exclusive lock</source>
        <translation>Ανίκανος να πάρει αποκλειστικό κλείδωμα</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>Μια άλλη εφαρμογή διαχείρισης πακέτων (όπως Synaptic η apt-get), βρίσκεται ήδη σε λειτουργία. Κλείστε πρώτα την εφαρμογή.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="77"/>
        <source>You must run this program as root.</source>
        <translation>Πρέπει να τρέξετε αυτή την εφασρμογή ως Root. </translation>
    </message>
</context>
</TS>
